<?php

namespace Pinpoint\SalesRep\Helper;

use Magento\Framework\App\Area;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\MailException;
use Magento\Framework\Mail\Template\TransportBuilder;
use Magento\Framework\Translate\Inline\StateInterface;
use Magento\Sales\Model\Order;
use Magento\Store\Api\Data\StoreInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;
use Psr\Log\LoggerInterface;

/**
 * Class Data
 */
class Data extends AbstractHelper
{
    const EMAIL_TEMPLATE = 'email_section/sendmail/email_template';

    const EMAIL_SERVICE_ENABLE = 'email_section/sendmail/enabled';

    /**
     * @var StateInterface
     */
    private StateInterface $inlineTranslation;

    /**
     * @var TransportBuilder
     */
    private TransportBuilder $transportBuilder;

    /**
     * @var StoreManagerInterface
     */
    private StoreManagerInterface $storeManager;

    /**
     * @var LoggerInterface
     */
    private LoggerInterface $logger;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $config;

    /**
     * Data constructor.
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param TransportBuilder $transportBuilder
     * @param StateInterface $inlineTranslation
     * @param LoggerInterface $logger
     * @param ScopeConfigInterface $config
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        TransportBuilder $transportBuilder,
        StateInterface $inlineTranslation,
        LoggerInterface $logger,
        ScopeConfigInterface $config
    ) {
        $this->storeManager = $storeManager;
        $this->transportBuilder = $transportBuilder;
        $this->inlineTranslation = $inlineTranslation;
        $this->logger = $logger;
        $this->config = $config;
        parent::__construct($context);
    }

    /**
     * Send Mail
     *
     * @param $user_name
     * @param $emailto
     * @param Order $order
     * @param string $comment
     * @return $this
     *
     * @throws LocalizedException
     * @throws MailException
     */
    public function sendMail($user_name, $emailto, Order $order, $comment = '')
    {
        if ($this->config->getValue(self::EMAIL_SERVICE_ENABLE)) {
            $this->inlineTranslation->suspend();
            $storeId = $this->getStoreId();

            /* email template */
            $template = $this->scopeConfig->getValue(
                self::EMAIL_TEMPLATE,
                ScopeInterface::SCOPE_STORE,
                $storeId
            );

            $vars = [
                'order' => $order,
                'name' => $user_name,
                'comment' => $comment,
                'store' => $this->getStore()
            ];

            // set from email
            $sender = $this->scopeConfig->getValue(
                'email_section/sendmail/sender',
                ScopeInterface::SCOPE_STORE,
                $this->getStoreId()
            );

            $transport = $this->transportBuilder->setTemplateIdentifier(
                $template
            )->setTemplateOptions(
                [
                    'area' => Area::AREA_FRONTEND,
                    'store' => $this->getStoreId()
                ]
            )->setTemplateVars(
                $vars
            )->setFromByScope(
                $sender
            )->addTo(
                $emailto
            )->getTransport();

            try {
                $transport->sendMessage();
            } catch (\Exception $exception) {
                $this->logger->critical($exception->getMessage());
            }
            $this->inlineTranslation->resume();
        }

        return $this;
    }

    /**
     * Get Current store id
     */
    public function getStoreId(): int
    {
        return $this->storeManager->getStore()->getId();
    }

    /**
     * Get Current store Info
     */
    public function getStore(): StoreInterface
    {
        return $this->storeManager->getStore();
    }
}
